# SPDX-License-Identifier: MIT
# Copyright 2020-2023 Big Bad Wolf Security, LLC

from . import data

__all__ = ["data"]
__version__ = "0.1.0"

actions = data.actions
services = data.services
resource_types = data.resource_types
